<?php

namespace Drupal\svg_sprite\TwigExtension;

use Drupal\Core\Template\Attribute;
use Twig\Extension\AbstractExtension;
use Twig\TwigFunction;

/**
 * Twig extension to display a svg sprite.
 *
 * @link https://drupaljournal.com/article/drupal/creating-custom-twig-functions-and-filters-drupal
 */
class SvgSpriteExtension extends AbstractExtension {

  /**
   * SVG sprite twig functions.
   *
   * @return \Twig\TwigFunction[]
   *   TwigFunction array.
   */
  public function getFunctions() {
    return [
      new TwigFunction('svg_sprite',
        [$this, 'displaySvgSprite'],
        ['is_safe' => ['html']]
      ),
    ];
  }

  /**
   * Provides a render array for an SVG sprite.
   *
   * @param string $sprite_id
   *   Valid sprite id.
   *
   * @return array|string
   *   NUll or render array of block.
   */
  public function displaySvgSprite(string $sprite_id) {

    if ($sprite_id) {
      $attributes = new Attribute(['class' => ['sprite']]);
      return [
        '#theme' => 'svg_sprite',
        '#attributes' => $attributes,
        '#sprite_id' => $sprite_id,
      ];
    }

    return '';
  }

}
